YARP 2.3.12 (2011-09-13)                                              {#v2_3_12}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.10...v2.3.12`):

```
    15  Paul Fitzpatrick <paulfitz@alum.mit.edu>
     7  Andrea Del Prete <andrea.delprete@iit.it>
     5  Ali Paikan <ali.paikan@iit.it>
     5  Lorenzo Natale <lorenzo.natale@iit.it>
     2  Ugo Pattacini <ugo.pattacini@iit.it>
     1  Alessandro Scalzo <alessandro.scalzo@iit.it>
     1  Marco Randazzo <marco.randazzo@iit.it>
```
